@@ -1,5 +1,6 @@
 utils::globalVariables(
     c(".index", ".key", ".value", ".model_id", ".loadings", ".model", ".model_desc",
       ".pred", ".predictions", ".resample_results", ".row_id", ".preds", ".type",
-      "n", ".resample_id", ".", "rowid..")
+      "n", ".resample_id", ".", "rowid..", "..rowid", "x", "d", "s", "id",
+      "direction", "metric", ".error_desc")
 )
